<?php

/**
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if( !class_exists( 'sheeba_lite_admin_notice' ) ) {

	class sheeba_lite_admin_notice {
	
		/**
		 * Constructor
		 */
		 
		public function __construct( $fields = array() ) {

			if ( 
				!get_option( 'sheeba-lite-dismissed-notice') &&
				version_compare( PHP_VERSION, SHEEBA_LITE_MIN_PHP_VERSION, '>=' )
			) {

				add_action( 'admin_notices', array(&$this, 'admin_notice') );
				add_action( 'admin_head', array( $this, 'dismiss' ) );
				add_action( 'admin_init', array(&$this, 'add_script') ,11);

            }

		}

		 /**
		 * Loads the notice style
		 */

		public function add_script() {

			global $wp_version;

			$file_dir = get_template_directory_uri() . '/core/admin/assets/';
			wp_enqueue_style ( 'sheeba-lite-notice', $file_dir.'css/notice.css' );

		}
        
        /**
		 * Dismiss notice.
		 */
		
		public function dismiss() {

			if ( isset( $_GET['sheeba-lite-dismiss'] ) && check_admin_referer( 'sheeba-lite-dismiss-action' ) ) {
		
				update_option( 'sheeba-lite-dismissed-notice', intval($_GET['sheeba-lite-dismiss']) );
				remove_action( 'admin_notices', array(&$this, 'admin_notice') );
				
			} 
		
		}

		/**
		 * Admin notice.
		 */
		 
		public function admin_notice() {
			
		?>
			
            <div class="notice notice-warning is-dismissible">

            	<p>
            
            		<strong>

                        <?php esc_html_e( 'Upgrade to the premium version of Sheeba, to enable 600+ Google Fonts, unlimited widget areas, portfolio section and much more. ', 'sheeba-lite' ); ?>
                    
                    </strong>
                
                </p>
                
                <p class="notice-coupon-message">

                    <span class="dashicon dashicons dashicons-yes-alt" size="10"></span>
                    <?php esc_html_e( 'Unlock a 20% discount on all plans now! Use the limited-time coupon code', 'sheeba-lite' ); ?>
                    <strong><?php esc_html_e( 'SHEEBA20', 'sheeba-lite' ); ?></strong>
                
                </p>

                <p>
            
                    <?php

                        printf( 
                            '<a href="%1$s" class="dismiss-notice">' . esc_html__( 'Dismiss this notice', 'sheeba-lite' ) . '</a>', 
                            esc_url( wp_nonce_url( add_query_arg( 'sheeba-lite-dismiss', '1' ), 'sheeba-lite-dismiss-action'))
                        );

                    ?>
                    
            	</p>
                    
            	<p>

            		<a class="button button-primary" target="_blank" href="<?php echo esc_url( 'https://www.themeinprogress.com/sheeba-flexible-and-and-easy-to-use-wordpress-and-woocommerce-theme/?ref=2&campaign=sheeba-lite-notice' ); ?>" ><?php esc_html_e( 'Upgrade to Sheeba Premium', 'sheeba-lite' ); ?></a>
                
            	</p>

            </div>
		
		<?php
		
		}

	}

}

new sheeba_lite_admin_notice();

?>